@@ -89,17 +89,6 @@ static inline const char* glom_get_locale_date_format()
   if(!c_locale_date_format)
   {
     //Get the current LC_TIME value:
-
-    //Unset LANGUAGE because it affects what setlocale(LC_TIME, NULL) returns,
-    //though it doesn't affect what, for instance, printf() uses. So unsetting
-    //it lets us get the correct LC_TIME locale.
-    const char* ENV_LANGUAGE = "LANGUAGE";
-    char* language = getenv(ENV_LANGUAGE);
-    if(language)
-      language = g_strdup(language);
-
-    setenv(ENV_LANGUAGE, "", 1 /* replace */);
-
     //We copy the string because setlocale() probably returns the same array
     //each time.
     //Even when the LC_TIME environment variable is not set, we still seem
@@ -108,7 +97,7 @@ static inline const char* glom_get_locale_date_format()
     if(lc_time)
       lc_time = g_strdup(lc_time);
 
-    //std::cout << "DEBUG: LC_TIME: " << lc_time << std::endl;
+    std::cout << "DEBUG: LC_TIME: " << lc_time << std::endl;
 
     char* old_lc_messages = 0;
     bool changed_lc_messages = false;
@@ -150,14 +139,8 @@ static inline const char* glom_get_locale_date_format()
       setlocale(LC_MESSAGES, old_lc_messages);
     }
 
-    //Restore this:
-    if(language) { //setenv() can't take NULL for this.
-      setenv(ENV_LANGUAGE, language, 1 /* replace */);
-   }
-
     g_free(old_lc_messages);
     g_free(lc_time);
-    g_free(language);
   }
 
   //std::cout << G_STRFUNC << ": c_locale_date_format=" << c_locale_date_format << std::endl;
@@ -495,13 +478,9 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
     const double number = get_double_for_gda_value_numeric(value);
 
     //Get the locale-specific text representation, in the required format:
-    //TODO: Use std::to_string(), but with the correct locale.
     std::stringstream another_stream;
     another_stream.imbue(locale); //Tell it to parse stuff as per this locale.
 
-    const int precision = 10; //arbitrary default until we can use C++11: std::numeric_limits<decltype(number)>::max_digits10;
-    another_stream << std::setprecision(precision);
-
     //Numeric formatting:
     if(!iso_format)
     {
