@@ -196,6 +196,8 @@ Glib::ustring TranslatableItem::get_translatable_type_name_nontranslated(enumTra
     return "Custom Title";
   else if(item_type == TRANSLATABLE_TYPE_RELATIONSHIP)
     return "Relationship";
+  else if(item_type == TRANSLATABLE_TYPE_RELATIONSHIP)
+    return "Layout Item";
   else if(item_type == TRANSLATABLE_TYPE_PRINT_LAYOUT)
     return "Print Layout";
   else if(item_type == TRANSLATABLE_TYPE_REPORT)
@@ -203,9 +205,7 @@ Glib::ustring TranslatableItem::get_translatable_type_name_nontranslated(enumTra
   else if(item_type == TRANSLATABLE_TYPE_TABLE)
     return "Table";
   else if(item_type == TRANSLATABLE_TYPE_LAYOUT_ITEM)
-    return "Layout Item";
-  else if(item_type == TRANSLATABLE_TYPE_CUSTOM_TITLE)
-    return "Field Title";
+    return "Layout Group";
   else if(item_type == TRANSLATABLE_TYPE_BUTTON)
     return "Button";
   else if(item_type == TRANSLATABLE_TYPE_TEXTOBJECT)
@@ -230,6 +230,8 @@ Glib::ustring TranslatableItem::get_translatable_type_name(enumTranslatableItemT
     return _("Custom Title");
   else if(item_type == TRANSLATABLE_TYPE_RELATIONSHIP)
     return _("Relationship");
+  else if(item_type == TRANSLATABLE_TYPE_RELATIONSHIP)
+    return _("Layout Item");
   else if(item_type == TRANSLATABLE_TYPE_PRINT_LAYOUT)
     return _("Print Layout");
   else if(item_type == TRANSLATABLE_TYPE_REPORT)
@@ -237,7 +239,7 @@ Glib::ustring TranslatableItem::get_translatable_type_name(enumTranslatableItemT
   else if(item_type == TRANSLATABLE_TYPE_TABLE)
     return _("Table");
   else if(item_type == TRANSLATABLE_TYPE_LAYOUT_ITEM)
-    return _("Layout Item");
+    return _("Layout Group");
   else if(item_type == TRANSLATABLE_TYPE_BUTTON)
     return _("Button");
   else if(item_type == TRANSLATABLE_TYPE_TEXTOBJECT)
