@@ -26,6 +26,7 @@
 #include <libglom/data_structure/glomconversions.h>
 
 #include <giomm/file.h>
+#include <giomm/resource.h>
 #include <glibmm/convert.h>
 #include <glibmm/fileutils.h>
 #include <glibmm/miscutils.h>
@@ -1439,7 +1440,7 @@ std::string Utils::get_temp_file_path(const std::string& prefix, const std::stri
   try
   {
     const std::string prefix_pattern = prefix + "XXXXXX" + extension;
-    const int filehandle = Glib::file_open_tmp(filepath, prefix_pattern);
+    const int filehandle = Glib::file_open_tmp(filepath, prefix);
     ::close(filehandle);
   }
   catch(const Glib::Error& ex)
@@ -1569,4 +1570,9 @@ bool Utils::script_check_for_pygtk2(const Glib::ustring& script)
   return true;
 }
 
+bool Utils::get_resource_exists(const std::string& resource_path)
+{
+  return Gio::Resource::get_file_exists_global_nothrow(resource_path);
+}
+
 } //namespace Glom
