@@ -519,7 +519,7 @@ Gtk::TreeView* Dialog_Layout_Report::get_selected_treeview()
       return m_treeview_parts_footer;
     default:
     {
-      std::cerr << "Dialog_Layout_Report::get_selected_treeview(): Unrecognised current notebook page:"  << m_notebook_parts->get_current_page() << std::endl;
+      std::cerr << G_STRFUNC << ": Dialog_Layout_Report::get_selected_treeview(): Unrecognised current notebook page:"  << m_notebook_parts->get_current_page() << std::endl;
       return 0;
     }
   }
@@ -895,6 +895,9 @@ void Dialog_Layout_Report::on_button_edit()
               {
                 Dialog_GroupBy* dialog = 0;
                 Utils::get_glade_widget_derived_with_warning(dialog);
+                if(!dialog)
+                  return;
+
                 add_view(dialog);
                 dialog->set_item(group_by, m_table_name);
                 dialog->set_transient_for(*this);
